@@ -19,8 +19,8 @@ import langtrace_python_sdk.langtrace as langtrace
 from langtrace_python_sdk import with_langtrace_root_span
 
 # Set these environment variables
-WCS_DEMO_URL = "WEVIATE CLUSTER URL"
-WCS_DEMO_RO_KEY = "<WEAVIATE API KEY>"
+WCS_DEMO_URL = os.environ["WCS_DEMO_URL"]
+WCS_DEMO_RO_KEY = os.environ["WCS_DEMO_RO_KEY"]
 
 # Connect to a WCS instance
 client = weaviate.connect_to_wcs(
@@ -30,7 +30,7 @@ client = weaviate.connect_to_wcs(
     headers={"X-OpenAI-Api-Key": os.environ["OPENAI_APIKEY"]},
 )
 
-langtrace.init(api_key="asdf", write_spans_to_console=True, batch=False)
+langtrace.init()
 
 
 @with_langtrace_root_span()
